keyserver-client

Run it like this

1. `pip install  keyserver-client  --extra-index-url=https://EDHBZzybsBduR147s2JY@repo.fury.io/realgeeks/`
2. `keyserver-client`

It runs in a while loop and continually refreshes the `~/.ssh/authorized_keys file`


# changelog
* 0.3.0 - add python3 support
